import { LRUCache } from './lru-cache';
/**
 * Time-aware, least-recently-used cache (TLRU). Variant of LRU where entries have valid lifetime.
 * @param {number} maxSize - Maximum cache size
 * @param {number} ttl - Time in milliseconds after which cache entry will evict itself
 * @param {number} evictionInterval - Frequency of cache entries eviction check
 **/
export declare class TLRUCache extends LRUCache {
    readonly maxSize: number;
    readonly ttl: number;
    private readonly cacheEntriesTTLRegistry;
    constructor(maxSize: number, ttl: number);
    private getCacheEntryEvictionTime;
    private clearCacheEntryEvictionTimeIfExists;
    private isCacheEntryValid;
    private setCacheEntryEvictionTime;
    private resetCacheEntryEvictionTime;
    private evictExpiredCacheEntries;
    entries(): IterableIterator<[string, string]>;
    keys(): IterableIterator<string>;
    values(): IterableIterator<string>;
    delete(key: string): boolean;
    has(key: string): boolean;
    get(key: string): string | undefined;
    set(key: string, value: string): this;
}
//# sourceMappingURL=tlru-cache.d.ts.map