"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigurationWireHelper = void 0;
const api_endpoints_1 = require("../api-endpoints");
const http_client_1 = require("../http-client");
const configuration_wire_types_1 = require("./configuration-wire-types");
/**
 * Helper class for fetching and converting configuration from the Eppo API(s).
 */
class ConfigurationWireHelper {
    /**
     * Build a new ConfigurationHelper for the target SDK Key.
     * @param sdkKey
     */
    static build(sdkKey, opts = { sdkName: 'android', sdkVersion: '4.0.0' }) {
        const { sdkName, sdkVersion, baseUrl } = opts;
        return new ConfigurationWireHelper(sdkKey, sdkName, sdkVersion, baseUrl);
    }
    constructor(sdkKey, targetSdkName = 'android', targetSdkVersion = '4.0.0', baseUrl) {
        const queryParams = {
            sdkName: targetSdkName,
            sdkVersion: targetSdkVersion,
            apiKey: sdkKey,
        };
        const apiEndpoints = new api_endpoints_1.default({
            baseUrl,
            queryParams,
        });
        this.httpClient = new http_client_1.default(apiEndpoints, 5000);
    }
    /**
     * Fetches configuration data from the API and build a Bootstrap Configuration (aka an `IConfigurationWire` object).
     * The IConfigurationWire instance can be used to bootstrap some SDKs.
     */
    async fetchBootstrapConfiguration() {
        // Get the configs
        let banditResponse;
        const configResponse = await this.httpClient.getUniversalFlagConfiguration();
        if (!configResponse?.flags) {
            console.warn('Unable to fetch configuration, returning empty configuration');
            return Promise.resolve(configuration_wire_types_1.ConfigurationWireV1.empty());
        }
        const flagsHaveBandits = Object.keys(configResponse.banditReferences ?? {}).length > 0;
        if (flagsHaveBandits) {
            banditResponse = await this.httpClient.getBanditParameters();
        }
        return configuration_wire_types_1.ConfigurationWireV1.fromResponses(configResponse, banditResponse);
    }
}
exports.ConfigurationWireHelper = ConfigurationWireHelper;
//# sourceMappingURL=configuration-wire-helper.js.map