"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigurationWireV1 = exports.ObfuscatedPrecomputedConfigurationResponse = exports.PrecomputedConfigurationResponse = exports.PrecomputedConfiguration = void 0;
exports.inflateResponse = inflateResponse;
exports.deflateResponse = deflateResponse;
const interfaces_1 = require("../interfaces");
const obfuscation_1 = require("../obfuscation");
// Base class for configuration responses with common fields
class BasePrecomputedConfigurationResponse {
    constructor(subjectKey, subjectAttributes, environment) {
        this.subjectKey = subjectKey;
        this.subjectAttributes = subjectAttributes;
        this.environment = environment;
        this.format = interfaces_1.FormatEnum.PRECOMPUTED;
        this.createdAt = new Date().toISOString();
    }
}
class PrecomputedConfiguration {
    constructor(response, subjectKey, subjectAttributes) {
        this.response = response;
        this.subjectKey = subjectKey;
        this.subjectAttributes = subjectAttributes;
    }
    static obfuscated(subjectKey, flags, bandits, salt, subjectAttributes, environment) {
        const response = new ObfuscatedPrecomputedConfigurationResponse(subjectKey, flags, bandits, salt, subjectAttributes, environment);
        return new PrecomputedConfiguration(JSON.stringify(response), subjectKey, subjectAttributes);
    }
    static unobfuscated(subjectKey, flags, bandits, subjectAttributes, environment) {
        const response = new PrecomputedConfigurationResponse(subjectKey, flags, bandits, subjectAttributes, environment);
        return new PrecomputedConfiguration(JSON.stringify(response), subjectKey, subjectAttributes);
    }
}
exports.PrecomputedConfiguration = PrecomputedConfiguration;
class PrecomputedConfigurationResponse extends BasePrecomputedConfigurationResponse {
    constructor(subjectKey, flags, bandits, subjectAttributes, environment) {
        super(subjectKey, subjectAttributes, environment);
        this.flags = flags;
        this.bandits = bandits;
        this.obfuscated = false;
    }
}
exports.PrecomputedConfigurationResponse = PrecomputedConfigurationResponse;
class ObfuscatedPrecomputedConfigurationResponse extends BasePrecomputedConfigurationResponse {
    constructor(subjectKey, flags, bandits, salt, subjectAttributes, environment) {
        super(subjectKey, subjectAttributes, environment);
        this.obfuscated = true;
        this.salt = salt;
        this.bandits = (0, obfuscation_1.obfuscatePrecomputedBanditMap)(this.salt, bandits);
        this.flags = (0, obfuscation_1.obfuscatePrecomputedFlags)(this.salt, flags);
    }
}
exports.ObfuscatedPrecomputedConfigurationResponse = ObfuscatedPrecomputedConfigurationResponse;
function inflateResponse(response) {
    return JSON.parse(response);
}
function deflateResponse(value) {
    return JSON.stringify(value);
}
class ConfigurationWireV1 {
    constructor(precomputed, config, bandits) {
        this.precomputed = precomputed;
        this.config = config;
        this.bandits = bandits;
        this.version = 1;
    }
    static fromResponses(flagConfig, banditConfig, flagConfigEtag, banditConfigEtag) {
        return new ConfigurationWireV1(undefined, {
            response: deflateResponse(flagConfig),
            fetchedAt: new Date().toISOString(),
            etag: flagConfigEtag,
        }, banditConfig
            ? {
                response: deflateResponse(banditConfig),
                fetchedAt: new Date().toISOString(),
                etag: banditConfigEtag,
            }
            : undefined);
    }
    static precomputed(precomputedConfig) {
        return new ConfigurationWireV1(precomputedConfig);
    }
    static empty() {
        return new ConfigurationWireV1();
    }
}
exports.ConfigurationWireV1 = ConfigurationWireV1;
//# sourceMappingURL=configuration-wire-types.js.map